
/** @file sector_decomposition.h
 *
 * Top level include file for the library.
 * This file should be included by all applications using the library.
 *
 */

/*
 *  Copyright (C) 2007 Stefan Weinzierl
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/** \mainpage Sector decomposition
 *
 * \author Christian Bogner and Stefan Weinzierl
 * \version 1.1.2
 *
 * The program "sector_decomposition" can be used to compute numerically the Laurent expansion
 * of (divergent) multi-loop Feynman integrals.
 *
 * The library is described in :
 * Christian Bogner and Stefan Weinzierl, "Resolution of singularities for multi-loop integrals",
 *  http://arXiv.org/abs/0709.4092 .
 *
 * With version 1.1.0 the following functionality has been added:
 *  - The integration domains can be chosen as the standard simplex or as the standard hyper-cube.
 *  - Exponents may contain rational numbers.
 *
 * Downloads for the nestedsums library:
 * The current version is 1.1.2. It requires at least GiNaC version 1.3.0.
 * The source code can be downloaded from
 *  http://particlephysics.uni-mainz.de/weinzierl/download/sector_decomposition-1.1.2.tar.gz
 *
 * The library is written in C++ and uses the GiNaC library and the GNU Scientific Library.
 * GiNaC can be obtained from
 *  http://www.ginac.de .
 * The GNU Scientific Library can be obtained from
 *  http://www.gnu.org/software/gsl .
 *
 * Documentation of the library is inserted as comment lines inside the source
 * code and can be extracted with the help of the documentation system "doxygen".
 * Doxygen is available from
 *  http://www.stack.nl/~dimitri/doxygen .
 *
 * When the library is used for scientific work that leads to publication in a 
 * scientific journal, please refer to this program as :
 *  Christian Bogner and Stefan Weinzierl, "Resolution of singularities for multi-loop integrals",
 *  arXiv:0709.4092 [hep-ph].
 *
 */ 

/** \namespace sector_decomposition
 *
 * All classes and functions of the "Sector Decomposition" package are defined
 * in the sector_decomposition namespace.
 *
 */

#ifndef __SECTOR_DECOMPOSITION_SECTOR_DECOMPOSITION_H__
#define __SECTOR_DECOMPOSITION_SECTOR_DECOMPOSITION_H__

#include "basic_sector_decomposition.h"
#include "integrand.h"
#include "polyhedra.h"
#include "monte_carlo.h"
#include "misc.h"
#include "constants.h"
#include "multi_index.h"
#include "code_generation.h"

#endif // ndef __SECTOR_DECOMPOSITION_SECTOR_DECOMPOSITION_H__

